@@ -1,4 +1,4 @@
-//$Id: app-win.cc,v 1.4 2001/05/02 14:01:34 cactus Exp $ -*- c++ -*-
+//$Id: app-win.cc,v 1.5 2001/08/10 16:10:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,10 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
+#ifdef USE_WM_ICONS
+#include <libgnomeui/gnome-window-icon.h>
+#endif
+
 #include "widgets/propertytable.h"
 #include "widgets/entry.h"
 
@@ -35,6 +39,10 @@ GUI::AppWindow::AppWindow (Resources::Application *res_):
     window->set_policy (false, true, false);
     window->delete_event.connect (SigC::slot (this, &AppWindow::delete_event_impl));
 
+#ifdef USE_WM_ICONS
+    gnome_window_icon_set_from_file (window->gtkobj (), GNOME_ICONDIR "/guikachu.png");
+#endif    
+
     GUI::PropertyTable *proptable = new GUI::PropertyTable ();
     Gtk::Entry *control;
     
