@@ -1,4 +1,4 @@
-//$Id: app-win.h,v 1.2 2001/04/03 16:02:47 cactus Exp $ -*- c++ -*-
+//$Id: app-win.h,v 1.4 2001/05/02 14:01:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,9 +30,6 @@ namespace Guikachu
 #include "app-res.h"
 
 #include <gtk--/window.h>
-#include <gtk--/entry.h>
-
-#include <glade/glade-xml.h>
 
 namespace Guikachu
 {
@@ -40,14 +37,8 @@ namespace Guikachu
     {
 	class AppWindow: public SigC::Object
 	{
+	    Gtk::Window            *window;
 	    Resources::Application *res;
-	    
-	    GladeXML    *gui;
-	    Gtk::Window *window;
-	    
-	    Gtk::Entry  *iconname_entry;
-	    Gtk::Entry  *version_entry;
-	    Gtk::Entry  *vendor_entry;
 
 	public:
 	    AppWindow (Resources::Application *res);
@@ -57,11 +48,6 @@ namespace Guikachu
 	private:
 	    int delete_event_impl (GdkEventAny *e);
 	    void update ();
-	    bool update_block;
-	    
-	    void iconname_entry_cb ();
-	    void version_entry_cb  ();
-	    void vendor_entry_cb   ();
 	};
     };
 };
