@@ -1,4 +1,4 @@
-//$Id: dialog-win.cc,v 1.11 2001/04/17 17:20:35 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.cc,v 1.12 2001/07/14 15:09:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,10 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
+#ifdef USE_WM_ICONS
+#include <libgnomeui/gnome-window-icon.h>
+#endif
+
 #include <gtk--/menu.h>
 #include <gnome--/dialog.h>
 #include <sigc++/retbind.h>
@@ -44,6 +48,10 @@ GUI::DialogWindow::DialogWindow (Resources::Dialog *res_):
     window = wrap (GTK_WINDOW (glade_xml_get_widget (gui, "res_dialog")));
     window->delete_event.connect (slot (this, &DialogWindow::delete_event_impl));
 
+#ifdef USE_WM_ICONS
+    gnome_window_icon_set_from_file (window->gtkobj (), GNOME_ICONDIR "/guikachu.png");
+#endif    
+
 
     // Widgets for page 1
     id_entry = wrap (GTK_ENTRY (glade_xml_get_widget (gui, "dialog_name")));
