@@ -1,4 +1,4 @@
-//$Id: button-canvas.cc,v 1.4 2001/06/09 13:23:20 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.cc,v 1.5 2001/07/24 01:48:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,7 +20,7 @@
 
 #include "form-editor.h"
 
-#include <gnome--.h>
+#include <gnome--/canvas-polygon.h>
 
 using namespace Guikachu::GUI::FormEditor;
 
