@@ -1,4 +1,4 @@
-//$Id: button-prop.cc,v 1.7 2001/04/22 13:03:11 cactus Exp $ -*- c++ -*-
+//$Id: button-prop.cc,v 1.9 2001/04/28 16:26:30 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -94,21 +94,26 @@ ButtonProperties::ButtonProperties (Button *res_):
 	slot (res, &Widgets::Button::get_repeat),
 	slot (res, &Widgets::Button::set_repeat),
 	res->changed);
-    proptable->add (_("Repeating:"), *manage (control));
+    proptable->add (_("Repeating:"), *manage (control),
+		    _("Repeating buttons fire multiple ButtonPress "
+		      "signals when kept pressed"));
 
     /* Usable */
     control = new GUI::ToggleButton (
 	slot (res, &Widgets::Button::get_usable),
 	slot (res, &Widgets::Button::set_usable),
 	res->changed);
-    proptable->add (_("Usable:"), *manage (control));
+    proptable->add (_("Usable:"), *manage (control),
+		    _("Non-usable widgets are not rendered by default"));
 
     /* Anchor right */
     control = new GUI::ToggleButton (
 	slot (res, &Widgets::Button::get_anchor_right),
 	slot (res, &Widgets::Button::set_anchor_right),
 	res->changed);
-    proptable->add (_("Anchor right:"), *manage (control));
+    proptable->add (_("Anchor right:"), *manage (control),
+		    _("Keep right aligned when changing label "
+		      "text at run-time"));
 
     /* Separator */
     proptable->add_separator ();
@@ -118,14 +123,18 @@ ButtonProperties::ButtonProperties (Button *res_):
 	slot (res, &Widgets::Button::get_x),
 	slot (res, &Widgets::Button::set_x),
 	res->changed);
-    proptable->add (_("X:"), *manage (control));
+    proptable->add (_("X:"), *manage (control),
+		    _("Horizontal position of the widget, relative "
+		      "to the parent form"));
 
     /* Y */
     control = new GUI::PosEntry (
 	slot (res, &Widgets::Button::get_y),
 	slot (res, &Widgets::Button::set_y),
 	res->changed);
-    proptable->add (_("Y:"), *manage (control));
+    proptable->add (_("Y:"), *manage (control),
+		    _("Vertical position of the widget, relative "
+		      "to the parent form"));
 
     /* Width */
     control = new GUI::PosEntry (
@@ -137,7 +146,9 @@ ButtonProperties::ButtonProperties (Button *res_):
 	slot (res, &Widgets::Button::get_manual_width),
 	slot (res, &Widgets::Button::set_manual_width),
 	res->changed);
-    proptable->add (_("Width:"), *manage (control));
+    proptable->add (_("Width:"), *manage (control),
+		    _("Horizontal size of the widget "
+		      "(check to set manually)"));
 
     /* Height */
     control = new GUI::PosEntry (
@@ -149,7 +160,9 @@ ButtonProperties::ButtonProperties (Button *res_):
 	slot (res, &Widgets::Button::get_manual_height),
 	slot (res, &Widgets::Button::set_manual_height),
 	res->changed);
-    proptable->add (_("Height:"), *manage (control));
+    proptable->add (_("Height:"), *manage (control),
+		    _("Vertical size of the widget "
+		      "(check to set manually)"));
     
     proptable->show ();
     property_editor = manage (proptable);
