@@ -1,4 +1,4 @@
-//$Id: canvasitem.cc,v 1.3 2001/06/09 13:23:20 cactus Exp $ -*- c++ -*-
+//$Id: canvasitem.cc,v 1.4 2001/08/13 16:22:05 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -217,7 +217,7 @@ void CanvasItem::drag_end (GdkEvent *e)
     
     if (drag_context.drag_occured)
     {
-	widget->set_x (drag_context.last_x - drag_context.offset_x);
-	widget->set_y (drag_context.last_y - drag_context.offset_y);
+	widget->set_x ((int)(drag_context.last_x - drag_context.offset_x));
+	widget->set_y ((int)(drag_context.last_y - drag_context.offset_y));
     }
 }
