@@ -1,4 +1,4 @@
-//$Id: checkbox-canvas.h,v 1.1 2001/04/30 20:47:27 cactus Exp $ -*- c++ -*-
+//$Id: checkbox-canvas.h,v 1.2 2001/05/14 16:54:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,13 +32,12 @@ namespace Guikachu
 	    class CheckboxCanvasItem: public CanvasItem
 	    {
 		Widgets::Checkbox *widget;
-		FormEditor::Form    *form;
 		Gnome::CanvasGroup  *group;
 	    public:
 		CheckboxCanvasItem (Widgets::Checkbox *widget,
-				      FormEditor::Form    *form);
+				    FormEditor::Form  *form);
 	    private:
-		void update ();
+		virtual void update ();
 	    };
 	}
     }
