@@ -1,4 +1,4 @@
-//$Id: form-editor.h,v 1.7 2001/05/17 20:50:52 cactus Exp $ -*- c++ -*-
+//$Id: form-editor.h,v 1.9 2001/07/05 22:25:14 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,28 +26,38 @@
 #define GUIKACHU_SCREEN_WIDTH 160
 #define GUIKACHU_SCREEN_HEIGHT 160
 
-#include <gdk/gdktypes.h>
 #include <gnome--/canvas.h>
 #include <gtk/gtkpacker.h> /* For GtkAnchor */
 
+#include "font.h"
+
 namespace Guikachu
 {
     namespace GUI
     {
 	namespace FormEditor
 	{
-	    GdkFont *get_font (int font_num);
-	    GdkFont *get_title_font ();
+	    Font &get_font (int font_num);
+	    Font &get_title_font ();
 	    
-	    int get_font_height (int font_num);
-	    int get_string_width (int font_num, const string& text);
+	    unsigned int get_font_height (int font_num);
+	    unsigned int get_string_width (int font_num, const string& text);
 	    
 	    Gnome::CanvasItem* draw_text (Gnome::CanvasGroup &group,
-					  const string &text, int font_num,
+					  const string &text,
+					  int font_num,
 					  int x, int y,
 					  bool usable = true,
 					  GtkAnchorType anchor = GTK_ANCHOR_NW,
 					  int clip_width = 0, int clip_height = 0);
+
+	    Gnome::CanvasItem* render_text (Gnome::CanvasGroup &group,
+					    const string    &text,
+					    const Font      &font,
+					    const Gdk_Color &color,
+					    int x, int y,
+					    GtkAnchorType anchor = GTK_ANCHOR_NW,
+					    int clip_width = 0, int clip_height = 0);
 	}
     }
 }
