@@ -1,4 +1,4 @@
-//$Id: form.cc,v 1.14 2001/07/08 17:03:11 cactus Exp $ -*- c++ -*-
+//$Id: form.cc,v 1.17 2001/08/13 16:22:05 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,9 +21,13 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
-#include <gnome--.h>
+#include <gnome--/canvas-group.h>
+#include <gnome--/canvas-polygon.h>
+#include <gnome--/canvas-rect.h>
 #include <sigc++/retbind.h>
 
+#include <list>
+
 #include "form-editor.h"
 
 using namespace Guikachu::GUI::FormEditor;
@@ -35,7 +39,6 @@ Form::Form (Resources::Form *res_,
     res (res_),
     win (win_),
     editor (res),
-    canvas (win->get_canvas ()),
     group (0),
     frame_group (0),
     title_group (0),
@@ -43,14 +46,17 @@ Form::Form (Resources::Form *res_,
 {
     using namespace SigC;
 
-    Gnome::CanvasRect *background =
-	new Gnome::CanvasRect ((*canvas->root ()),
+    Gnome::CanvasGroup *root = win->get_canvas ()->root ();
+    root->lower_to_bottom ();
+    
+    Gnome::CanvasRect *background = 
+	new Gnome::CanvasRect (*root,
 			       0, 0,
 			       GUIKACHU_SCREEN_WIDTH, GUIKACHU_SCREEN_HEIGHT);
     background->set_width_pixels (0);
     background->set_fill_color (GUIKACHU_BGC);
     
-    group = new Gnome::CanvasGroup (*(canvas->root ()), 0, 0);
+    group = new Gnome::CanvasGroup (*root, 0, 0);
     group->event.connect (slot (this, &Form::canvas_event_cb));
     
     res->changed.connect (slot (this, &Form::update));
@@ -296,8 +302,8 @@ int Form::canvas_event_cb (GdkEvent *e)
 	
 	if (drag_occured)
 	{
-	    res->set_x (last_x - offset_x);
-	    res->set_y (last_y - offset_y);
+	    res->set_x ((int)(last_x - offset_x));
+	    res->set_y ((int)(last_y - offset_y));
 	}
     }
 
