@@ -1,4 +1,4 @@
-//$Id: form.h,v 1.6 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: form.h,v 1.7 2001/08/10 16:10:35 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -35,7 +35,7 @@ namespace Guikachu
 #include "form-prop.h"
 
 #include <string>
-#include <gnome--/canvas.h>
+#include <gnome--/canvas-group.h>
 #include <sigc++/object.h>
 
 namespace Guikachu
@@ -49,7 +49,6 @@ namespace Guikachu
 		Resources::Form *res;
 		GUI::FormWindow *win;
 		FormProperties   editor;
-		Gnome::Canvas   *canvas;
 		
 		Gnome::CanvasGroup *group;
 		Gnome::CanvasGroup *frame_group;
