@@ -1,4 +1,4 @@
-//$Id: graffiti-canvas.cc,v 1.3 2001/05/14 16:54:11 cactus Exp $ -*- c++ -*-
+//$Id: graffiti-canvas.cc,v 1.4 2001/07/24 01:48:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,7 +20,7 @@
 
 #include "form-editor.h"
 
-#include <gnome--.h>
+#include <gnome--/canvas-polygon.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gnome-canvas-pixbuf.h>
 
