@@ -1,4 +1,4 @@
-//$Id: graffiti-canvas.h,v 1.1 2001/04/30 20:47:27 cactus Exp $ -*- c++ -*-
+//$Id: graffiti-canvas.h,v 1.2 2001/05/14 16:54:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,13 +32,12 @@ namespace Guikachu
 	    class GraffitiCanvasItem: public CanvasItem
 	    {
 		Widgets::Graffiti  *widget;
-		FormEditor::Form   *form;
 		Gnome::CanvasGroup *group;
 	    public:
 		GraffitiCanvasItem (Widgets::Graffiti *res,
 				    FormEditor::Form  *form);
 	    private:
-		void update ();
+		virtual void update ();
 	    };
 	}
     }
