@@ -1,4 +1,4 @@
-//$Id: graffiti-prop.h,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: graffiti-prop.h,v 1.2 2001/04/25 16:05:25 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -44,10 +44,7 @@ namespace Guikachu
 	{
 	    class GraffitiProperties: public SigC::Object
 	    {
-		Widgets::Graffiti *res;
-		
-		/* Property editor */
-		Gtk::Widget       *property_editor;
+		Gtk::Widget *property_editor;
 		
 	    public:
 		GraffitiProperties (Widgets::Graffiti *res);
