@@ -1,4 +1,4 @@
-//$Id: widget.h,v 1.15 2001/05/11 16:37:08 cactus Exp $ -*- c++ -*-
+//$Id: widget.h,v 1.17 2001/08/10 16:10:35 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,13 +25,15 @@ namespace Guikachu
     {
 	enum Type
 	{
+	    WIDGET_NONE,
 	    WIDGET_LABEL,
 	    WIDGET_BUTTON,
 	    WIDGET_PUSHBUTTON,
 	    WIDGET_GRAFFITI,
 	    WIDGET_SELECTOR_TRIGGER,
 	    WIDGET_CHECKBOX,
-	    WIDGET_LIST
+	    WIDGET_LIST,
+	    WIDGET_POPUP_TRIGGER
 	};
 
 	class Widget;
