@@ -1,4 +1,4 @@
-//$Id: form-res-io.cc,v 1.13 2001/05/06 17:45:13 cactus Exp $ -*- c++ -*-
+//$Id: form-res-io.cc,v 1.14 2001/07/11 19:26:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -173,6 +173,8 @@ Widgets::Widget* Form::load_widget (xmlDocPtr doc,
 	widget = create_widget (Widgets::WIDGET_CHECKBOX, id);
     else if (!strcmp (node_name, "list"))
 	widget = create_widget (Widgets::WIDGET_LIST, id);
+    else if (!strcmp (node_name, "popup_trigger"))
+	widget = create_widget (Widgets::WIDGET_POPUP_TRIGGER, id);
     else
 	g_warning ("Unknown widget type `%s'", node_name);
 
@@ -271,6 +273,12 @@ void Form::save (xmlNodePtr node) const
 	    case Widgets::WIDGET_LIST:
 		curr_node_name = (xmlChar*) "list";
 		break;
+	    case Widgets::WIDGET_POPUP_TRIGGER:
+		curr_node_name = (xmlChar*) "popup_trigger";
+		break;
+	    default:
+		g_assert_not_reached ();
+		break;
 	    }
 	    
 	    widget_node = xmlNewChild (widgetlist_node, NULL, curr_node_name, NULL);
