@@ -1,4 +1,4 @@
-//$Id: form-res.cc,v 1.15 2001/05/17 22:08:54 cactus Exp $ -*- c++ -*-
+//$Id: form-res.cc,v 1.16 2001/07/11 19:26:46 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,6 +26,7 @@
 #include "form-editor/selector-trigger.h"
 #include "form-editor/checkbox.h"
 #include "form-editor/list.h"
+#include "form-editor/popup-trigger.h"
 
 using namespace Guikachu::Resources;
 using namespace Guikachu;
@@ -93,6 +94,13 @@ Widgets::Widget* Form::create_widget (Widgets::Type type)
     case Widgets::WIDGET_LIST:
 	prefix = "list";
 	break;
+    case Widgets::WIDGET_POPUP_TRIGGER:
+	prefix = "popup_trigger";
+	break;
+    default:
+	g_assert_not_reached ();
+	return 0;
+	break;
     }
     
     return create_widget (type, ResourceManager::create_id (prefix));
@@ -129,6 +137,13 @@ Widgets::Widget* Form::create_widget (Widgets::Type type,
     case Widgets::WIDGET_LIST:
 	widget = new Widgets::List (this, id);
 	break;
+    case Widgets::WIDGET_POPUP_TRIGGER:
+	widget = new Widgets::PopupTrigger (this, id);
+	break;
+    default:
+	g_assert_not_reached ();
+	return 0;
+	break;
     }
     
     widgets.insert (widget);
