@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.19 2001/07/05 18:07:05 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.22 2001/08/10 16:10:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,32 +21,39 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
+#include "form-editor/palette.h"
+
 #include <gtk--/treeitem.h>
 #include <gtk--/table.h>
 #include <gtk--/button.h>
 #include <gtk--/pixmap.h>
 #include <gtk--/menu.h>
 
+#include <gdk--/cursor.h>
+
+#include <gnome--/canvas-group.h>
+#include <gnome--/canvas-polygon.h>
+
 #include "form-win-helpers.h"
+#include "form-editor/form-editor.h"
 
 using namespace Guikachu::GUI;
 using namespace Guikachu::Resources;
 
-#include "pixmaps/label.xpm"
-#include "pixmaps/button.xpm"
-#include "pixmaps/pushbutton.xpm"
-#include "pixmaps/graffiti.xpm"
-#include "pixmaps/selector-trigger.xpm"
-#include "pixmaps/checkbox.xpm"
-#include "pixmaps/list.xpm"
+// Static members of FormWindow
+static Guikachu::GUI::Palette *palette = 0;
+
 
 FormWindow::FormWindow (Form *res_):
     res (res_),
-    edited_widget (0)
+    edited_widget (0),
+    canvas_overlay (0),
+    selected_widget_type (Widgets::WIDGET_NONE)
 {
     gui = glade_xml_new (GLADEDIR "/guikachu.glade", 0);
 
     using namespace Gtk;
+    using namespace SigC;
     
     window = wrap (GTK_WINDOW (glade_xml_get_widget (gui, "res_form")));
     window->delete_event.connect (slot (this, &FormWindow::delete_event_impl));
@@ -58,8 +65,6 @@ FormWindow::FormWindow (Form *res_):
     
     canvas = wrap (GNOME_CANVAS (glade_xml_get_widget (gui, "form_canvas")));
     Gtk::Tree *tree = wrap (GTK_TREE (glade_xml_get_widget (gui, "form_tree")));
-
-    create_palette ();
     
     FormWindow_Helpers::TopTreeItem *item = new FormWindow_Helpers::TopTreeItem (res);
     item->show ();
@@ -81,55 +86,11 @@ FormWindow::FormWindow (Form *res_):
     res->widget_created.connect (slot (this, &FormWindow::widget_created_cb));
     res->widget_removed.connect (slot (this, &FormWindow::widget_removed_cb));
     update ();
-}
+    
+    if (!palette)
+	palette = new Guikachu::GUI::Palette ();
+    palette->palette_changed.connect (slot (this, &FormWindow::palette_cb));
 
-void FormWindow::create_palette ()
-{
-    using namespace Gtk;
-    using namespace SigC;
-    
-    Table *palette = wrap (GTK_TABLE (glade_xml_get_widget (gui, "form_palette")));
-    
-#define PALETTE_ADD_BUTTON(type,tip,xpm,x,y)				\
-    {									\
-	Button *button = new Button;					\
-	button->set_relief (GTK_RELIEF_NONE);				\
-	button->add (*manage (new Gtk::Pixmap (xpm)));			\
-	button->clicked.connect (					\
-	    bind (slot (this, &FormWindow::add_widget_cb), type));	\
-	tips.set_tip (*button, tip);					\
-	palette->attach (*manage (button), x, (x + 1), y, (y + 1),	\
-	    0, 0);							\
-    }
-    
-    PALETTE_ADD_BUTTON(Widgets::WIDGET_LABEL,
-		       _("Static text label"), label_xpm,
-		       0, 0);
-    PALETTE_ADD_BUTTON(Widgets::WIDGET_GRAFFITI,
-		       _("Graffiti state indicator"), graffiti_xpm,
-		       2, 0);    
-
-    PALETTE_ADD_BUTTON(Widgets::WIDGET_BUTTON,
-		       _("Clickable button"), button_xpm,
-		       0, 1);
-    PALETTE_ADD_BUTTON(Widgets::WIDGET_PUSHBUTTON,
-		       _("Pushbutton"), pushbutton_xpm,
-		       1, 1);
-    PALETTE_ADD_BUTTON(Widgets::WIDGET_SELECTOR_TRIGGER,
-		       _("Pushbutton"), selector_trigger_xpm,
-		       2, 1);
-    
-    PALETTE_ADD_BUTTON(Widgets::WIDGET_CHECKBOX,
-		       _("Check box"), checkbox_xpm,
-		       0, 2);
-
-    /*
-    PALETTE_ADD_BUTTON(Widgets::WIDGET_LIST,
-		       _("List"), list_xpm,
-		       2, 2);
-    */
-		       
-#undef PALETTE_ADD_BUTTON
 }
 
 FormWindow::~FormWindow ()
@@ -145,7 +106,8 @@ void FormWindow::show ()
 {
     window->show_all ();
     window->get_window ().raise ();
-
+    palette->show_all ();
+    
     if (edited_widget)
 	edited_widget->show_editor ();
     else
@@ -218,9 +180,69 @@ void FormWindow::widget_removed_cb (Widgets::Widget *widget)
     itemlist.erase (i);
 }
 
-void FormWindow::add_widget_cb (Widgets::Type type)
+int FormWindow::canvas_overlay_cb (GdkEvent *event)
 {
-    res->create_widget (type);
+    if (event->type != GDK_BUTTON_PRESS)
+	return false;
+
+    if (event->button.button != 1)
+	return false;
+    
+    add_widget (event->button.x - res->get_x (),
+		event->button.y - res->get_y ());
+    
+    palette->palette_applied ();
+
+    return true;
+}
+
+void FormWindow::palette_cb (Widgets::Type type)
+{
+    if (type == selected_widget_type)
+	return;
+
+    selected_widget_type = type;
+    delete canvas_overlay;
+    canvas_overlay = 0;
+    
+    // Change pointer
+    Gdk_Window window = canvas->get_window ();
+    if (type == Widgets::WIDGET_NONE)
+    {
+	Gdk_Cursor cursor (0);
+	window.set_cursor (cursor);
+	return;
+
+    } else {
+	
+	Gdk_Cursor cursor (GDK_CROSSHAIR);
+	window.set_cursor (cursor);
+    }
+    
+			   
+    // Create overlay canvas item
+    Gnome::CanvasPoints   points;
+
+    int x = res->get_x ();
+    int y = res->get_y ();
+    
+    points.push_back (Gnome::Art::Point (x, y));
+    points.push_back (Gnome::Art::Point (GUIKACHU_SCREEN_WIDTH + x, y));
+    points.push_back (Gnome::Art::Point (GUIKACHU_SCREEN_WIDTH + x, GUIKACHU_SCREEN_HEIGHT + y));
+    points.push_back (Gnome::Art::Point (x, GUIKACHU_SCREEN_HEIGHT + y));
+    points.push_back (Gnome::Art::Point (x, y));
+    
+    canvas_overlay = new Gnome::CanvasPolygon (*canvas->root (), points);
+    canvas_overlay->event.connect (slot (this, &FormWindow::canvas_overlay_cb));
+    canvas_overlay->raise_to_top ();
+}
+
+void FormWindow::add_widget (int x, int y)
+{
+    Widgets::Widget *widget = res->create_widget (selected_widget_type);
+
+    widget->set_x (x);
+    widget->set_y (y);
 }
 
 void FormWindow::show_property_editor (Widgets::Widget *widget)
