@@ -1,4 +1,4 @@
-//$Id: form-win.h,v 1.10 2001/07/05 18:07:05 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.12 2001/08/10 16:10:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,7 +33,6 @@ namespace Guikachu
 
 #include <gtk--/window.h>
 #include <gtk--/tree.h>
-#include <gtk--/tooltips.h>
 #include <gnome--/canvas.h>
 
 #include <glade/glade-xml.h>
@@ -44,19 +43,20 @@ namespace Guikachu
     {
 	class FormWindow: public SigC::Object
 	{
-	    Resources::Form     *res;
+	    Resources::Form            *res;
 	    
-	    GladeXML            *gui;
-	    Gtk::Window         *window;
-	    Gtk::Window         *property_window;
+	    GladeXML                   *gui;
+	    Gtk::Window                *window;
+	    Gtk::Window                *property_window;
 	    
-	    Gnome::Canvas       *canvas;
-	    Gtk::TreeItem       *top_treeitem;
-	    FormEditor::Form    *form;
+	    Gnome::Canvas              *canvas;
+	    Gtk::TreeItem              *top_treeitem;
+	    FormEditor::Form           *form;
 
-	    Gtk::Tooltips        tips;
+	    Widgets::Widget            *edited_widget;
 
-	    Widgets::Widget     *edited_widget;
+	    Gnome::CanvasItem          *canvas_overlay;
+	    Widgets::Type               selected_widget_type;	    
 	public:
 	    FormWindow (Resources::Form *res);
 	    ~FormWindow ();
@@ -64,8 +64,6 @@ namespace Guikachu
 	    
 	    Gnome::Canvas *get_canvas () const { return canvas; };
 	private:
-	    void create_palette ();
-
 	    void show_property_editor (Widgets::Widget *widget);
 	    void show_form_property_editor ();
 
@@ -73,7 +71,9 @@ namespace Guikachu
 	    int property_delete_event_impl (GdkEventAny *e);
 	    void update ();
 
-	    void add_widget_cb (Widgets::Type type);
+	    void palette_cb (Widgets::Type type);
+	    int canvas_overlay_cb (GdkEvent *event);
+	    void add_widget (int x, int y);	    
 
 	    void widget_created_cb (Widgets::Widget *widget);
 	    void widget_removed_cb (Widgets::Widget *widget);
