@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.11 2001/05/09 16:07:03 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.12 2001/08/10 16:10:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,10 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
+#ifdef USE_WM_ICONS
+#include <libgnomeui/gnome-window-icon.h>
+#endif
+
 #include <sigc++/retbind.h>
 #include "argumentsink.h"
 
@@ -38,6 +42,10 @@ GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
     window = wrap (GTK_WINDOW (glade_xml_get_widget (gui, "res_menu")));
     window->delete_event.connect (slot (this, &MenuWindow::delete_event_impl));
 
+#ifdef USE_WM_ICONS
+    gnome_window_icon_set_from_file (window->gtkobj (), GNOME_ICONDIR "/guikachu.png");
+#endif    
+
     id_entry = wrap (GTK_ENTRY (glade_xml_get_widget (gui, "menu_id")));
 
     // Menu items list
