@@ -1,4 +1,4 @@
-//$Id: resource-manager.cc,v 1.6 2001/03/11 18:16:16 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.8 2001/04/21 13:02:59 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -64,7 +64,7 @@ string ResourceManager::create_id (const string& prefix)
     return ret_val;
 }
 
-bool ResourceManager::register_resource (const string& id)
+bool ResourceManager::register_id (const string& id)
 {
     if (id_set.find (id) != id_set.end ())
     {
@@ -78,7 +78,7 @@ bool ResourceManager::register_resource (const string& id)
     return true;
 }
 
-void ResourceManager::remove_resource (const string& id)
+void ResourceManager::unregister_id (const string& id)
 {
     id_set.erase (id);
 }
@@ -86,7 +86,7 @@ void ResourceManager::remove_resource (const string& id)
 Resources::Resource* ResourceManager::create_resource (Resources::Type type,
 						       const string& id)
 {
-    if (!register_resource (id))
+    if (!register_id (id))
 	return 0;
 	
     Resources::Resource *res;
@@ -103,7 +103,9 @@ Resources::Resource* ResourceManager::create_resource (Resources::Type type,
 	res = new Resources::Menu (id);
 	break;
     case Resources::RESOURCE_FORM:
-	res = new Resources::Form (id);
+	Resources::Form *form = new Resources::Form (id);
+	form->widget_changed.connect (SigC::slot (&ResourceManager::resource_changed_cb));
+	res = form;
 	break;
     }
     
@@ -158,7 +160,7 @@ void ResourceManager::remove_resource (Resources::Resource* resource)
 {
     resource_removed.emit (resource);
 
-    remove_resource (resource->get_id ());
+    unregister_id (resource->get_id ());
     resource_map.erase (resource->get_id ());
     
     delete resource;
