@@ -1,4 +1,4 @@
-//$Id: resource-manager.h,v 1.5 2001/03/03 14:10:15 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.h,v 1.6 2001/04/02 22:46:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -43,12 +43,13 @@ namespace Guikachu
     public:
 	static Resources::Resource* create_resource (Resources::Type type,
 						     const string& id);
-	static bool register_resource (const string& id);
-	static void remove_resource (const string& id);
 	static void remove_resource (Resources::Resource* resource);
 	static bool rename_resource (const string& old_id,
 				     const string& new_id);
 
+	static bool register_id (const string& id);
+	static void unregister_id (const string& id);
+
 	static string create_id (const string& prefix);
 
 	static set<Resources::Resource*> get_resources ();
