@@ -1,4 +1,4 @@
-//$Id: resource.cc,v 1.2 2001/02/24 16:04:14 cactus Exp $ -*- c++ -*-
+//$Id: resource.cc,v 1.3 2001/04/14 18:01:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -20,7 +20,7 @@
 
 using namespace Guikachu;
 
-string Resources::Resource::get_id () const
+string Resources::Resource::get_id ()
 {
     return id;
 };
