@@ -1,4 +1,4 @@
-//$Id: string-win.cc,v 1.6 2001/04/10 16:17:28 cactus Exp $ -*- c++ -*-
+//$Id: string-win.cc,v 1.7 2001/08/10 16:10:34 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,10 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
+#ifdef USE_WM_ICONS
+#include <libgnomeui/gnome-window-icon.h>
+#endif
+
 #include <sigc++/retbind.h>
 #include "argumentsink.h"
 
@@ -37,6 +41,10 @@ GUI::StringWindow::StringWindow (Guikachu::Resources::String *res_):
     window = wrap (GTK_WINDOW (glade_xml_get_widget (gui, "res_string")));
     window->delete_event.connect (slot (this, &StringWindow::delete_event_impl));
     
+#ifdef USE_WM_ICONS
+    gnome_window_icon_set_from_file (window->gtkobj (), GNOME_ICONDIR "/guikachu.png");
+#endif    
+
     id_entry = wrap (GTK_ENTRY (glade_xml_get_widget (gui, "str_name")));
     text_entry = wrap (GTK_TEXT (glade_xml_get_widget (gui, "str_text")));
     
