@@ -1,4 +1,4 @@
-//$Id: string-list.h,v 1.1 2001/05/11 16:37:09 cactus Exp $ -*- c++ -*-
+//$Id: string-list.h,v 1.3 2001/08/10 16:10:36 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,6 +22,7 @@
 #include <gtk--/box.h>
 #include <gtk--/list.h>
 #include <gtk--/button.h>
+#include <gtk--/entry.h>
 
 #include <vector>
 
@@ -31,15 +32,18 @@ namespace Guikachu
     {
 	class StringList: public Gtk::HBox
 	{
-	    typedef SigC::Slot0<vector<string> > get_slot_t;
-	    typedef SigC::Slot1<void, const vector<string>&> set_slot_t;
+	    typedef vector<string> value_t;
+
+	    typedef SigC::Slot0<value_t> get_slot_t;
+	    typedef SigC::Slot1<void, const value_t&> set_slot_t;
 	    typedef SigC::Signal0<void> changed_t;
 	    
 	    get_slot_t get_val;
 	    set_slot_t set_val;
 
-	    Gtk::List   *string_list;
+	    Gtk::List   *list_widget;
 	    Gtk::Button *btnAdd, *btnUp, *btnDown, *btnRemove;
+	    Gtk::Entry  *entry;
 	    
 	public:
 	    StringList (get_slot_t get_slot,
@@ -55,6 +59,8 @@ namespace Guikachu
 	    void button_up_cb ();
 	    void button_down_cb ();
 	    void button_remove_cb ();
+
+	    void entry_activate_cb ();
 	};
     }
 }
